"""XUI Views"""

from django.contrib.auth.mixins import LoginRequiredMixin
from django.views import generic


class ProfileView(LoginRequiredMixin, generic.TemplateView):
    """User Profile view"""

    template_name = "allauth_xui/profile.html"



"""AppConf for allauth_xui"""

from django.apps import AppConfig


class AllAuthUIConfig(AppConfig):
    """App configuration for allauth_xui"""

    name = "allauth_xui"
    default_auto_field = "django.db.models.BigAutoField"
